# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Clone
Version:	0.46
Release:	1.%{__distinit}%{__distvers}
Summary:	Recursively copy perl data types
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Clone
Source0:	https://cpan.metacpan.org/modules/by-module/Clone/Clone-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(warnings)
# Module Runtime
BuildRequires:	perl(AutoLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(utf8)
BuildRequires:	perl(vars)
# Optional Tests
BuildRequires:	perl(B)
BuildRequires:	perl(B::COW) >= 0.004
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Devel::Peek)
BuildRequires:	perl(Hash::Util::FieldHash)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Storable)
BuildRequires:	perl(Taint::Runtime)
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
This module provides a clone() method that makes recursive
copies of nested hash, array, scalar and reference types,
including tied variables and objects.

clone() takes a scalar argument and an optional parameter that
can be used to limit the depth of the copy. To duplicate lists,
arrays or hashes, pass them in by reference.

%prep
%setup -q -n Clone-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README.md
%{perl_vendorarch}/auto/Clone/
%{perl_vendorarch}/Clone.pm
%{_mandir}/man3/Clone.3*

%changelog
* Wed Oct 19 2022 Paul Howarth <paul@city-fan.org> - 0.46-1
- Update to 0.46
  - Fix backwards compatibility with older perls
  - Bump MANIFEST to include extra tests
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 0.45-8
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.45-4
- Perl 5.34 rebuild

* Thu Jun 25 2020 Paul Howarth <paul@city-fan.org> - 0.45-2
- Perl 5.32 rebuild

* Fri Apr 24 2020 Paul Howarth <paul@city-fan.org> - 0.45-1
- Update to 0.45
  - Bump B::COW requirement to fix big-endian issue

* Mon Apr 20 2020 Paul Howarth <paul@city-fan.org> - 0.44-1
- Update to 0.44
  - Support Perls with COW disabled
  - Bump B::COW requirement for testing

* Tue Jul 30 2019 Paul Howarth <paul@city-fan.org> - 0.43-1
- Update to 0.43
  - Fix an issue when cloning a NULL mg_ptr pointer

* Mon Jul 22 2019 Paul Howarth <paul@city-fan.org> - 0.42-1
- Update to 0.42
  - Make handling of mg_ptr safer
  - Change license wording on some test files to make the entire dist
    released under the same terms as Perl itself (GH#20)

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.41-3
- Perl 5.30 rebuild

* Fri Oct 26 2018 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41
  - Check the CowREFCNT of a COWed PV; this should fix some issues people have
    been having with 0.40 on DBD drives and DBIx::Class
  - Make buildtools files not executable

* Wed Oct 24 2018 Paul Howarth <paul@city-fan.org> - 0.40-1
- Update to 0.40
  - Reuse COWed PV when cloning (fixes CPAN RT#97535)
  - Extra protection against potential infinite loop
  - Improved tests

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 0.39-7
- Perl 5.28 rebuild

* Wed Mar 28 2018 Paul Howarth <paul@city-fan.org> - 0.39-6
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Fri Apr  7 2017 Paul Howarth <paul@city-fan.org> - 0.39-1
- Update to 0.39
  - Use explicit '.' in tests since it may not be in @INC any longer in newer
    perls (CPAN RT#120648)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel and perl(Hash::Util::FieldHash) unconditionally

* Wed Sep 28 2016 Paul Howarth <paul@city-fan.org> - 0.38-6
- Fix FTBFS when perl is not in the minimal buildroot

* Tue May 17 2016 Paul Howarth <paul@city-fan.org> - 0.38-5
- BR: perl-devel and perl-generators where available
- Simplify find commands with -delete

* Fri Jan 30 2015 Paul Howarth <paul@city-fan.org> - 0.38-1
- Update to 0.38
  - Typo fixes and improvements to the README
  - travis/coveralls integration
- Classify buildreqs by usage

* Thu Aug 28 2014 Paul Howarth <paul@city-fan.org> - 0.37-2
- Perl 5.20 rebuild

* Fri May 16 2014 Paul Howarth <paul@city-fan.org> - 0.37-1
- Update to 0.37:
  - Removed Carp dependency
  - Silenced some clang warnings
  - Added a README
- Drop %%defattr, redundant since rpm 4.4

* Mon Dec  9 2013 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36:
  - Fixed compilation issue on AIX and C89

* Thu Sep  5 2013 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35:
  - SV's can be NULL (shit happens) (CPAN RT#86217)
  - Making tests compatible with older versions of Test::More
- Drop patch for building with Test::More < 0.88, no longer needed

* Tue Jul 23 2013 Paul Howarth <paul@city-fan.org> - 0.34-4
- Perl 5.18 rebuild

* Mon Dec 10 2012 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34:
  - Made some tests optional (CPAN RT#81774)
  - Modernized synopsis
- Don't need to take action to avoid trying to use Hash::Util::FieldHash now
- Update patch for building with Test::More < 0.88

* Mon Nov 26 2012 Paul Howarth <paul@city-fan.org> - 0.33-1
- Update to 0.33:
  - Fix typo in croak message

* Thu Nov 22 2012 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32:
  - Stop skipping SvROK handling for all magical scalars; this fixes
    CPAN RT#67105, CPAN RT#79730 and CPAN RT#80201
  - Made the Changes file compliant to the CPAN::Changes spec
  - Fixed tests when Scalar::Util::weaken is not available
  - Removed dubious documentation on the optional parameter until it is
    'fixed'; right now it just increases the refcount when it's 0, and clones
    otherwise - which isn't exactly what it says (CPAN RT#57773)
  - Updated remark on Storable's dclone() to address CPAN RT#50174
  - Updated Makefile.PL to include test dependencies
- Add patch to support building with Test::More < 0.88
- This release by GARU -> update source URL
- BR: perl(Scalar::Util) and perl(Storable)
- Don't run the new t/08fieldhash.t test if we have Perl < 5.10 and hence no
  Hash::Util::FieldHash

* Wed Jun 20 2012 Paul Howarth <paul@city-fan.org> - 0.31-11
- Drop redundant BR: perl(ExtUtils::ParseXS)

* Mon Jun 18 2012 Paul Howarth <paul@city-fan.org> - 0.31-10
- BR: perl(AutoLoader), perl(Carp), perl(Data::Dumper) and perl(Exporter)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Wed Jun 22 2011 Paul Howarth <paul@city-fan.org> - 0.31-7
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.31-6
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 0.31-5
- Fix dist tag for RHEL-6 Beta

* Thu Feb 18 2010 Paul Howarth <paul@city-fan.org> - 0.31-4
- Dist tag for Rawhide no longer needs special-casing

* Mon Sep  7 2009 Paul Howarth <paul@city-fan.org> - 0.31-3
- Use %%{?perl_default_filter} for perl shared objects

* Sun Mar  1 2009 Paul Howarth <paul@city-fan.org> - 0.31-2
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31

* Fri Dec 12 2008 Paul Howarth <paul@city-fan.org> - 0.30-1
- Update to 0.30

* Wed Sep  3 2008 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29
- Add buildreq perl(ExtUtils::MakeMaker)

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 0.28-5
- Import from Fedora

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.28-4
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.28-3
- Autorebuild for GCC 4.3

* Fri Jan 11 2008 Tom "spot" Callaway <tcallawa@redhat.com> 0.28-2
- Rebuild for new perl

* Wed Nov 28 2007 Tom "spot" Callaway <tcallawa@redhat.com> 0.28-1
- Bump to 0.28

* Fri Aug 24 2007 Tom "spot" Callaway <tcallawa@redhat.com> 0.27-2
- License fix

* Fri Jul 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 0.27-1
- Bump to 0.27

* Wed Jan 17 2007 Tom "spot" Callaway <tcallawa@redhat.com> 0.22-1
- Bump to 0.22

* Fri Sep 15 2006 Tom "spot" Callaway <tcallawa@redhat.com> 0.20-2
- Bump for fc6

* Fri Mar 31 2006 Tom "spot" Callaway <tcallawa@redhat.com> 0.20-1
- Bump to 0.20
- New BR: perl-Taint-Runtime

* Tue Feb 28 2006 Tom "spot" Callaway <tcallawa@redhat.com> 0.18-3
- Bump for FC-5

* Fri Jan  6 2006 Tom "spot" Callaway <tcallawa@redhat.com> 0.18-2
- Don't pass optflags twice
- Remove .bs files

* Thu Jan  5 2006 Tom "spot" Callaway <tcallawa@redhat.com> 0.18-1
- Initial package for Fedora Extras
